@@ -1123,3 +1123,31 @@ _clutter_paint_node_create (GType gtype)
 
   return (gpointer) g_type_create_instance (gtype);
 }
+
+static ClutterPaintNode *
+clutter_paint_node_get_root (ClutterPaintNode *node)
+{
+  ClutterPaintNode *iter;
+
+  iter = node;
+  while (iter != NULL && iter->parent != NULL)
+    iter = iter->parent;
+
+  return iter;
+}
+
+CoglFramebuffer *
+clutter_paint_node_get_framebuffer (ClutterPaintNode *node)
+{
+  ClutterPaintNode *root = clutter_paint_node_get_root (node);
+  ClutterPaintNodeClass *klass;
+
+  if (root == NULL)
+    return NULL;
+
+  klass = CLUTTER_PAINT_NODE_GET_CLASS (root);
+  if (klass->get_framebuffer != NULL)
+    return klass->get_framebuffer (root);
+
+  return cogl_get_draw_framebuffer ();
+}
